.. highlight:: shell

============
Installation
============


Stable release
--------------

To install nidhoggr-requests, run this command in your terminal:

.. code-block:: console

    $ pip install nidhoggr_requests

This is the preferred method to install nidhoggr-requests, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for nidhoggr-requests can be downloaded from the `MC4EP repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone https://git.mc4ep.org/mc4ep/nidhoggr-requests.git

Or download the `tarball`_:

.. code-block:: console

    $ curl -OJL https://git.mc4ep.org/mc4ep/nidhoggr-requests/archive/master.tar.gz

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _MC4EP repo: https://git.mc4ep.org/mc4ep/nidhoggr-requests
.. _tarball: https://git.mc4ep.org/mc4ep/nidhoggr-requests/archive/master.tar.gz
